@@ -1,6 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
-/*
- * SPDX-FileCopyrightText: 2018 Sébastien Wilmet <swilmet@gnome.org>
+/* SPDX-FileCopyrightText: 2018-2020 Sébastien Wilmet <swilmet@gnome.org>
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
@@ -468,12 +467,17 @@ static void
 dh_web_view_constructed (GObject *object)
 {
         DhWebView *view = DH_WEB_VIEW (object);
+        WebKitWebContext *webkit_context;
         WebKitSettings *webkit_settings;
         DhSettings *dh_settings;
 
         if (G_OBJECT_CLASS (dh_web_view_parent_class)->constructed != NULL)
                 G_OBJECT_CLASS (dh_web_view_parent_class)->constructed (object);
 
+        webkit_context = webkit_web_view_get_context (WEBKIT_WEB_VIEW (view));
+        if (!webkit_web_context_get_sandbox_enabled (webkit_context))
+                g_warning_once ("WebKitWebContext is not sandboxed.");
+
         webkit_settings = webkit_web_view_get_settings (WEBKIT_WEB_VIEW (view));
         webkit_settings_set_enable_back_forward_navigation_gestures (webkit_settings, TRUE);
 
@@ -673,7 +677,7 @@ dh_web_view_set_search_text (DhWebView   *view,
         if (search_text != NULL && search_text[0] != '\0') {
                 /* If webkit_find_controller_search() is called a second time
                  * with the same parameters it's not a NOP, it launches a new
-                 * search, apparently, which screws up search_next() and
+                 * search, apparently, which ruins search_next() and
                  * search_previous(). So we must call it only once for the same
                  * search string.
                  */
